---
name: Plugin Suggestion 📦
about: Suggest a new idea for the project.
labels: "new-plugin"
---

<!--
  To make it easier for us to help you, please include as much useful information as possible.

  Useful Links:
  - Wiki: https://docs.garak.ai/garak

  Before opening a new issue, please search existing issues https://github.com/NVIDIA/garak/issues
-->

## Summary

Brief explanation of the plugin (e.g. probe, generator, detector, ...).

### Basic example

If you have a Proof-of-Concept, blog post or any other useful references please let us know in this section.

### Motivation

Why are we doing this? What use cases does it support? What is the expected outcome?
